@@ -36,7 +36,7 @@
 
 /* Defines the poppler version. */
 #ifndef POPPLER_VERSION
-#define POPPLER_VERSION "25.05.0"
+#define POPPLER_VERSION "25.06.0"
 #endif
 
 /* Use single precision arithmetic in the Splash backend */
@@ -66,12 +66,12 @@
 
 /* Build against libtiff. */
 #ifndef ENABLE_LIBTIFF
-/* #undef ENABLE_LIBTIFF */
+#define ENABLE_LIBTIFF 1
 #endif
 
 /* Build against libpng. */
 #ifndef ENABLE_LIBPNG
-/* #undef ENABLE_LIBPNG */
+#define ENABLE_LIBPNG 1
 #endif
 
 /* Define to 1 if you have the <dirent.h> header file, and it defines `DIR'.
@@ -109,7 +109,7 @@
 
 /* Use header-only classes from Boost in the Splash backend */
 #ifndef USE_BOOST_HEADERS
-/* #undef USE_BOOST_HEADERS */
+#define USE_BOOST_HEADERS 1
 #endif
 
 //------------------------------------------------------------------------
